"""Dagua: GPU-accelerated differentiable graph layout engine built on PyTorch."""

__version__ = "0.0.2"

# Public API will be re-exported here once modules are implemented:
#   from dagua.elements import Node, Edge, Cluster
#   from dagua.graph import Graph
#   from dagua.style import NodeStyle, EdgeStyle, ClusterStyle
#   from dagua.defaults import set_default_device, set_default_theme
