"""Annealing schedules for constraint weights.

Controls how constraint weights evolve during optimization — e.g., start with
strong DAG ordering, then gradually increase repulsion. Enables curriculum-style
layout optimization.
"""
