"""Optional Graphviz passthrough — neato -n2 with fixed positions.

Writes a .dot file with pre-computed positions, renders via Graphviz's neato
engine with -n2 flag (use given positions). Requires graphviz Python package.
"""
